@@ -4,34 +4,31 @@ import sys
 import typing
 from collections import abc
 from enum import Enum
-from typing import (  # type: ignore[attr-defined]
+from typing import (
     TYPE_CHECKING,
     Any,
     Dict,
-    List,
+    ForwardRef,
     Optional,
     TypeVar,
     Union,
-    _eval_type,
+    cast,
 )
 from typing_extensions import Annotated, Self, get_args, get_origin
 
-from strawberry.exceptions.not_a_strawberry_enum import NotAStrawberryEnumError
-from strawberry.private import is_private
-
-try:
-    from typing import ForwardRef
-except ImportError:  # pragma: no cover
-    # ForwardRef is private in python 3.6 and 3.7
-    from typing import _ForwardRef as ForwardRef  # type: ignore
-
 from strawberry.custom_scalar import ScalarDefinition
 from strawberry.enum import EnumDefinition
-from strawberry.lazy_type import LazyType, StrawberryLazyReference
+from strawberry.exceptions.not_a_strawberry_enum import NotAStrawberryEnumError
+from strawberry.lazy_type import LazyType
+from strawberry.private import is_private
 from strawberry.type import StrawberryList, StrawberryOptional, StrawberryTypeVar
 from strawberry.types.types import TypeDefinition
 from strawberry.unset import UNSET
-from strawberry.utils.typing import is_generic, is_list, is_type_var, is_union
+from strawberry.utils.typing import (
+    eval_type,
+    is_generic,
+    is_type_var,
+)
 
 if TYPE_CHECKING:
     from strawberry.field import StrawberryField
@@ -74,60 +71,19 @@ class StrawberryAnnotation:
             return StrawberryAnnotation(annotation, namespace=namespace)
         return annotation
 
-    @staticmethod
-    def parse_annotated(annotation: object) -> object:
-        from strawberry.auto import StrawberryAuto
-
-        if is_private(annotation):
-            return annotation
-
-        annotation_origin = get_origin(annotation)
-
-        if annotation_origin is Annotated:
-            annotated_args = get_args(annotation)
-            annotation_type = annotated_args[0]
-
-            for arg in annotated_args[1:]:
-                if isinstance(arg, StrawberryLazyReference):
-                    assert isinstance(annotation_type, ForwardRef)
-
-                    return arg.resolve_forward_ref(annotation_type)
-
-                if isinstance(arg, StrawberryAuto):
-                    return arg
-
-            return StrawberryAnnotation.parse_annotated(annotation_type)
-
-        elif is_union(annotation):
-            return Union[
-                tuple(
-                    StrawberryAnnotation.parse_annotated(arg)
-                    for arg in get_args(annotation)
-                )  # pyright: ignore
-            ]  # pyright: ignore
-
-        elif is_list(annotation):
-            return List[StrawberryAnnotation.parse_annotated(get_args(annotation)[0])]  # type: ignore  # noqa: E501
-
-        elif annotation_origin and is_generic(annotation_origin):
-            args = get_args(annotation)
-
-            return annotation_origin[
-                tuple(StrawberryAnnotation.parse_annotated(arg) for arg in args)
-            ]
-
-        return annotation
-
     def resolve(self) -> Union[StrawberryType, type]:
-        annotation = self.parse_annotated(self.annotation)
+        annotation = self.annotation
+        if isinstance(annotation, str):
+            annotation = ForwardRef(annotation)
 
-        if isinstance(self.annotation, str):
-            annotation = ForwardRef(self.annotation)
-
-        evaled_type = _eval_type(annotation, self.namespace, None)
+        evaled_type = eval_type(annotation, self.namespace, None)
 
         if is_private(evaled_type):
             return evaled_type
+
+        if get_origin(evaled_type) is Annotated:
+            evaled_type = get_args(evaled_type)[0]
+
         if self._is_async_type(evaled_type):
             evaled_type = self._strip_async_type(evaled_type)
         if self._is_lazy_type(evaled_type):
@@ -153,7 +109,7 @@ class StrawberryAnnotation:
         elif self._is_union(evaled_type):
             return self.create_union(evaled_type)
         elif is_type_var(evaled_type) or evaled_type is Self:
-            return self.create_type_var(evaled_type)
+            return self.create_type_var(cast(TypeVar, evaled_type))
 
         # TODO: Raise exception now, or later?
         # ... raise NotImplementedError(f"Unknown type {evaled_type}")
