@@ -1,10 +1,13 @@
-import json
-from typing import Dict, Mapping, Optional
+from __future__ import annotations
 
-from typing_extensions import Literal
+import json
+from typing import TYPE_CHECKING, Dict, Mapping, Optional
 
 from strawberry.test import BaseGraphQLTestClient
 
+if TYPE_CHECKING:
+    from typing_extensions import Literal
+
 
 class GraphQLTestClient(BaseGraphQLTestClient):
     def _build_body(
@@ -13,7 +16,6 @@ class GraphQLTestClient(BaseGraphQLTestClient):
         variables: Optional[Dict[str, Mapping]] = None,
         files: Optional[Dict[str, object]] = None,
     ) -> Dict[str, object]:
-
         body: Dict[str, object] = {"query": query}
 
         if variables:
