@@ -1,9 +1,19 @@
+from __future__ import annotations
+
 import dataclasses
-from typing import Any, List, NamedTuple, NoReturn, Set, Tuple, Type, Union, cast
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    List,
+    NamedTuple,
+    NoReturn,
+    Set,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
-from pydantic import BaseModel
-from pydantic.fields import ModelField
-from pydantic.typing import NoArgAnyCallable
 from pydantic.utils import smart_deepcopy
 
 from strawberry.experimental.pydantic.exceptions import (
@@ -20,6 +30,11 @@ from strawberry.utils.typing import (
     is_optional,
 )
 
+if TYPE_CHECKING:
+    from pydantic import BaseModel
+    from pydantic.fields import ModelField
+    from pydantic.typing import NoArgAnyCallable
+
 
 def normalize_type(type_) -> Any:
     if is_list(type_):
@@ -85,7 +100,7 @@ def get_default_factory_for_field(
     # defining both default and default_factory is not supported
 
     if has_factory and has_default:
-        default_factory = cast(NoArgAnyCallable, default_factory)
+        default_factory = cast("NoArgAnyCallable", default_factory)
 
         raise BothDefaultAndDefaultFactoryDefinedError(
             default=default, default_factory=default_factory
@@ -94,7 +109,7 @@ def get_default_factory_for_field(
     # if we have a default_factory, we should return it
 
     if has_factory:
-        default_factory = cast(NoArgAnyCallable, default_factory)
+        default_factory = cast("NoArgAnyCallable", default_factory)
 
         return default_factory
 
