@@ -1,7 +1,10 @@
+from __future__ import annotations
+
 import json
 from datetime import timedelta
 from inspect import signature
 from typing import (
+    TYPE_CHECKING,
     Any,
     Awaitable,
     Callable,
@@ -14,41 +17,38 @@ from typing import (
 )
 
 from starlette import status
-from starlette.background import BackgroundTasks
+from starlette.background import BackgroundTasks  # noqa: TCH002
 from starlette.requests import HTTPConnection, Request
-from starlette.responses import HTMLResponse, PlainTextResponse, Response
-from starlette.types import ASGIApp
+from starlette.responses import (
+    HTMLResponse,
+    PlainTextResponse,
+    Response,
+)
 from starlette.websockets import WebSocket
 
 from fastapi import APIRouter, Depends
 from strawberry.exceptions import InvalidCustomContext, MissingQueryError
+from strawberry.fastapi.context import BaseContext, CustomContext
 from strawberry.fastapi.handlers import GraphQLTransportWSHandler, GraphQLWSHandler
 from strawberry.file_uploads.utils import replace_placeholders_with_files
 from strawberry.http import (
-    GraphQLHTTPResponse,
     parse_query_params,
     parse_request_data,
     process_result,
 )
-from strawberry.schema import BaseSchema
 from strawberry.schema.exceptions import InvalidOperationTypeError
 from strawberry.subscriptions import GRAPHQL_TRANSPORT_WS_PROTOCOL, GRAPHQL_WS_PROTOCOL
-from strawberry.types import ExecutionResult
 from strawberry.types.graphql import OperationType
 from strawberry.utils.debug import pretty_print_graphql_operation
 from strawberry.utils.graphiql import get_graphiql_html
 
-CustomContext = Union["BaseContext", Dict[str, Any]]
-MergedContext = Union[
-    "BaseContext", Dict[str, Union[Any, BackgroundTasks, Request, Response, WebSocket]]
-]
+if TYPE_CHECKING:
+    from starlette.types import ASGIApp
 
-
-class BaseContext:
-    def __init__(self):
-        self.request: Optional[Union[Request, WebSocket]] = None
-        self.background_tasks: Optional[BackgroundTasks] = None
-        self.response: Optional[Response] = None
+    from strawberry.fastapi.context import MergedContext
+    from strawberry.http import GraphQLHTTPResponse
+    from strawberry.schema import BaseSchema
+    from strawberry.types import ExecutionResult
 
 
 class GraphQLRouter(APIRouter):
@@ -312,14 +312,14 @@ class GraphQLRouter(APIRouter):
 
     async def execute(
         self,
-        query: str,
+        query: Optional[str],
         variables: Optional[Dict[str, Any]] = None,
         context: Any = None,
         operation_name: Optional[str] = None,
         root_value: Any = None,
         allowed_operation_types: Optional[Iterable[OperationType]] = None,
     ):
-        if self.debug:
+        if self.debug and query:
             pretty_print_graphql_operation(operation_name, query, variables)
 
         return await self.schema.execute(
@@ -339,14 +339,7 @@ class GraphQLRouter(APIRouter):
     async def execute_request(
         self, request: Request, response: Response, data: dict, context, root_value
     ) -> Response:
-        try:
-            request_data = parse_request_data(data)
-        except MissingQueryError:
-            missing_query_response = PlainTextResponse(
-                "No GraphQL query found in the request",
-                status_code=status.HTTP_400_BAD_REQUEST,
-            )
-            return self._merge_responses(response, missing_query_response)
+        request_data = parse_request_data(data)
 
         method = request.method
         allowed_operation_types = OperationType.from_http(method)
@@ -368,6 +361,12 @@ class GraphQLRouter(APIRouter):
                 e.as_http_error_reason(method),
                 status_code=status.HTTP_400_BAD_REQUEST,
             )
+        except MissingQueryError:
+            missing_query_response = PlainTextResponse(
+                "No GraphQL query found in the request",
+                status_code=status.HTTP_400_BAD_REQUEST,
+            )
+            return self._merge_responses(response, missing_query_response)
 
         response_data = await self.process_result(request, result)
 
