@@ -1,21 +1,26 @@
+from __future__ import annotations
+
 import json
-from typing import Dict
+from typing import TYPE_CHECKING, Dict
 
 from flask import Response, render_template_string, request
-from flask.typing import ResponseReturnValue
+
+if TYPE_CHECKING:
+    from flask.typing import ResponseReturnValue
+    from strawberry.http import GraphQLHTTPResponse
+    from strawberry.schema.base import BaseSchema
+    from strawberry.types import ExecutionResult
+
 from flask.views import View
 from strawberry.exceptions import MissingQueryError
 from strawberry.file_uploads.utils import replace_placeholders_with_files
 from strawberry.flask.graphiql import should_render_graphiql
 from strawberry.http import (
-    GraphQLHTTPResponse,
     parse_query_params,
     parse_request_data,
     process_result,
 )
-from strawberry.schema.base import BaseSchema
 from strawberry.schema.exceptions import InvalidOperationTypeError
-from strawberry.types import ExecutionResult
 from strawberry.types.graphql import OperationType
 from strawberry.utils.graphiql import get_graphiql_html
 
@@ -67,7 +72,6 @@ class GraphQLView(BaseGraphQLView):
                     status=400, response="Unable to parse request body as JSON"
                 )
         elif content_type.startswith("multipart/form-data"):
-
             try:
                 operations = json.loads(request.form.get("operations", "{}"))
                 files_map = json.loads(request.form.get("map", "{}"))
@@ -98,10 +102,7 @@ class GraphQLView(BaseGraphQLView):
         else:
             return Response("Unsupported Media Type", 415)
 
-        try:
-            request_data = parse_request_data(data)
-        except MissingQueryError:
-            return Response("No GraphQL query found in the request", 400)
+        request_data = parse_request_data(data)
 
         response = Response(status=200, content_type="application/json")
         context = self.get_context(response)
@@ -122,6 +123,8 @@ class GraphQLView(BaseGraphQLView):
             )
         except InvalidOperationTypeError as e:
             return Response(e.as_http_error_reason(method), 400)
+        except MissingQueryError:
+            return Response("No GraphQL query found in the request", 400)
 
         response_data = self.process_result(result)
         response.set_data(self.encode_json(response_data))
@@ -158,7 +161,6 @@ class AsyncGraphQLView(BaseGraphQLView):
                     status=400, response="Unable to parse request body as JSON"
                 )
         elif content_type.startswith("multipart/form-data"):
-
             try:
                 operations = json.loads(request.form.get("operations", "{}"))
                 files_map = json.loads(request.form.get("map", "{}"))
@@ -190,10 +192,7 @@ class AsyncGraphQLView(BaseGraphQLView):
         else:
             return Response("Unsupported Media Type", 415)
 
-        try:
-            request_data = parse_request_data(data)
-        except MissingQueryError:
-            return Response("No GraphQL query found in the request", 400)
+        request_data = parse_request_data(data)
 
         response = Response(status=200, content_type="application/json")
         context = await self.get_context(response)
@@ -216,6 +215,8 @@ class AsyncGraphQLView(BaseGraphQLView):
             )
         except InvalidOperationTypeError as e:
             return Response(e.as_http_error_reason(method), 400)
+        except MissingQueryError:
+            return Response("No GraphQL query found in the request", 400)
 
         response_data = await self.process_result(result)
         response.set_data(self.encode_json(response_data))
