@@ -1,12 +1,14 @@
+from __future__ import annotations
+
 import json
 from dataclasses import dataclass
-from typing import Any, Dict, List, Mapping, Optional
+from typing import TYPE_CHECKING, Any, Dict, List, Mapping, Optional
 from typing_extensions import TypedDict
 
 from graphql.error.graphql_error import format_error as format_graphql_error
 
-from strawberry.exceptions import MissingQueryError
-from strawberry.types import ExecutionResult
+if TYPE_CHECKING:
+    from strawberry.types import ExecutionResult
 
 
 class GraphQLHTTPResponse(TypedDict, total=False):
@@ -28,7 +30,9 @@ def process_result(result: ExecutionResult) -> GraphQLHTTPResponse:
 
 @dataclass
 class GraphQLRequestData:
-    query: str
+    # query is optional here as it can be added by an extensions
+    # (for example an extension for persisted queries)
+    query: Optional[str]
     variables: Optional[Dict[str, Any]]
     operation_name: Optional[str]
 
@@ -41,13 +45,8 @@ def parse_query_params(params: Dict[str, str]) -> Dict[str, Any]:
 
 
 def parse_request_data(data: Mapping[str, Any]) -> GraphQLRequestData:
-    query = data.get("query")
-
-    if not query:
-        raise MissingQueryError()
-
     return GraphQLRequestData(
-        query=data["query"],
+        query=data.get("query"),
         variables=data.get("variables"),
         operation_name=data.get("operationName"),
     )
