@@ -16,14 +16,7 @@ from typing import (
     overload,
 )
 
-from graphql import (
-    GraphQLArgument,
-    GraphQLEnumType,
-    GraphQLEnumValue,
-    GraphQLScalarType,
-    GraphQLUnionType,
-    is_union_type,
-)
+from graphql import is_union_type
 from graphql.language.printer import print_ast
 from graphql.type import (
     is_enum_type,
@@ -33,7 +26,6 @@ from graphql.type import (
     is_scalar_type,
     is_specified_directive,
 )
-from graphql.type.directives import GraphQLDirective
 from graphql.utilities.print_schema import (
     is_defined_type,
     print_block,
@@ -46,8 +38,6 @@ from graphql.utilities.print_schema import print_type as original_print_type
 
 from strawberry.custom_scalar import ScalarWrapper
 from strawberry.enum import EnumDefinition
-from strawberry.field import StrawberryField
-from strawberry.schema.schema_converter import GraphQLCoreConverter
 from strawberry.schema_directive import Location, StrawberrySchemaDirective
 from strawberry.type import StrawberryContainer
 from strawberry.unset import UNSET
@@ -55,6 +45,16 @@ from strawberry.unset import UNSET
 from .ast_from_value import ast_from_value
 
 if TYPE_CHECKING:
+    from graphql import (
+        GraphQLArgument,
+        GraphQLEnumType,
+        GraphQLEnumValue,
+        GraphQLScalarType,
+        GraphQLUnionType,
+    )
+    from graphql.type.directives import GraphQLDirective
+
+    from strawberry.field import StrawberryField
     from strawberry.schema import BaseSchema
 
 
@@ -226,6 +226,8 @@ def print_args(
 
 
 def print_fields(type_, schema: BaseSchema, *, extras: PrintExtras) -> str:
+    from strawberry.schema.schema_converter import GraphQLCoreConverter
+
     fields = []
 
     for i, (name, field) in enumerate(type_.fields.items()):
@@ -319,6 +321,8 @@ def print_enum(
 
 
 def print_extends(type_, schema: BaseSchema):
+    from strawberry.schema.schema_converter import GraphQLCoreConverter
+
     strawberry_type = type_.extensions and type_.extensions.get(
         GraphQLCoreConverter.DEFINITION_BACKREF
     )
@@ -330,6 +334,8 @@ def print_extends(type_, schema: BaseSchema):
 
 
 def print_type_directives(type_, schema: BaseSchema, *, extras: PrintExtras) -> str:
+    from strawberry.schema.schema_converter import GraphQLCoreConverter
+
     strawberry_type = type_.extensions and type_.extensions.get(
         GraphQLCoreConverter.DEFINITION_BACKREF
     )
@@ -387,6 +393,8 @@ def print_input_value(name: str, arg: GraphQLArgument) -> str:
 
 
 def _print_input_object(type_, schema: BaseSchema, *, extras: PrintExtras) -> str:
+    from strawberry.schema.schema_converter import GraphQLCoreConverter
+
     fields = []
     for i, (name, field) in enumerate(type_.fields.items()):
         strawberry_field = field.extensions and field.extensions.get(
