@@ -1,12 +1,15 @@
+from __future__ import annotations
+
 import dataclasses
-from typing import Dict, Union
+from typing import TYPE_CHECKING, Dict, Union
 
 from graphql import GraphQLField, GraphQLInputField, GraphQLType
 
-from strawberry.custom_scalar import ScalarDefinition
-from strawberry.enum import EnumDefinition
-from strawberry.types.types import TypeDefinition
-from strawberry.union import StrawberryUnion
+if TYPE_CHECKING:
+    from strawberry.custom_scalar import ScalarDefinition
+    from strawberry.enum import EnumDefinition
+    from strawberry.types.types import TypeDefinition
+    from strawberry.union import StrawberryUnion
 
 Field = Union[GraphQLInputField, GraphQLField]
 
