@@ -4,7 +4,7 @@ import inspect
 import sys
 import warnings
 from inspect import isasyncgenfunction, iscoroutinefunction
-from typing import (  # type: ignore[attr-defined]
+from typing import (
     TYPE_CHECKING,
     Any,
     Callable,
@@ -19,7 +19,6 @@ from typing import (  # type: ignore[attr-defined]
     Type,
     TypeVar,
     Union,
-    _eval_type,
     cast,
 )
 from typing_extensions import Annotated, Protocol, get_args, get_origin
@@ -30,6 +29,7 @@ from strawberry.exceptions import MissingArgumentsAnnotationsError
 from strawberry.type import StrawberryType
 from strawberry.types.info import Info
 from strawberry.utils.cached_property import cached_property
+from strawberry.utils.typing import eval_type
 
 if TYPE_CHECKING:
     import builtins
@@ -102,7 +102,7 @@ class ReservedType(NamedTuple):
         for parameter in parameters:
             annotation = parameter.annotation
             try:
-                resolved_annotation = _eval_type(
+                resolved_annotation = eval_type(
                     ForwardRef(annotation)
                     if isinstance(annotation, str)
                     else annotation,
